MIX_GetAudioDecoderFormat

Function MIX_GetAudioDecoderFormat 

pub unsafe extern "C" fn MIX_GetAudioDecoderFormat(
    audiodecoder: *mut MIX_AudioDecoder,
    spec: *mut SDL_AudioSpec,
) -> bool
Query the initial audio format of a MIX_AudioDecoder.

Note that some audio files can change format in the middle; some explicitly support this, but a more common example is two MP3 files concatenated together. In many cases, SDL_mixer will correctly handle these sort of files, but this function will only report the initial format a file uses.

Parameter: audiodecoder the audio decoder to query.

Parameter: spec on success, audio format details will be stored here.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL_mixer 3.0.0.