pub unsafe extern "C" fn MIX_CreateAudioDecoder(
path: *const c_char,
props: SDL_PropertiesID,
) -> *mut MIX_AudioDecoderExpand description
Create a MIX_AudioDecoder from a path on the filesystem.
Most apps won’t need this, as SDL_mixer’s usual interfaces will decode audio as needed. However, if one wants to decode an audio file into a memory buffer without playing it, this interface offers that.
This function allows properties to be specified. This is intended to supply file-specific settings, such as where to find SoundFonts for a MIDI file, etc. In most cases, the caller should pass a zero to specify no extra properties.
SDL_PropertiesID are discussed in SDL’s documentation .
When done with the audio decoder, it can be destroyed with MIX_DestroyAudioDecoder().
This function requires SDL_mixer to have been initialized with a successful call to MIX_Init(), but does not need an actual MIX_Mixer to have been created.
Parameter: path the path on the filesystem from which to load data.
Parameter: props decoder-specific properties. May be zero.
Returns: an audio decoder, ready to decode.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL_mixer 3.0.0.
See Also: MIX_CreateAudioDecoder_IO
See Also: MIX_DecodeAudio
See Also: MIX_DestroyAudioDecoder